@@ -6,7 +6,7 @@ class Filter:
     @classmethod
     def _prepare_array(cls, filter_in_items: list) -> str:
         """
-        Method for deserialize array of Any to string.
+        Method for deserializing array of Any to string.
         For example: List[1,2,3,4,5,] -> Str "1,2,3,4,5"
         :param filter_in_items: List of items
         :return: String row with concatenation of all array items.
@@ -23,9 +23,11 @@ class Filter:
     def build_filter(cls, filters: dict) -> str:
         """
         Creates url filter according to received dict.
-        For example: {"age": 22, "gender": "male"} to "?age=22&gender=male"
+        For example: {"age": 22, "gender": "male", "name_in": ["Inna", "Erich"]}
+        to "?age=22&gender=male&name_in=Inna,Erich"
+
         :param filters: Dict with filter items.
-        :return: String like that "?age=22&gender=male".
+        :return: Prepared filter string like that "?age=22&gender=male".
         """
         final_filter_row = ""
         for item in filters.keys():
